@@ -125,11 +125,7 @@ public:
 
     void render() override {
         m_plotter->drawPlots();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        m_plotter->window()->resetOpenGLState();
-#else
         m_plotter->window()->endExternalCommands();
-#endif
     }
 
     QOpenGLFramebufferObject *createFramebufferObject(const QSize &size) override
@@ -163,3 +159,5 @@ QImage Plotter3DRenderer::grabImage()
     }
     return ret;
 }
+
+#include "moc_graph3ditem.cpp"
